tdub.rex
--------

A module for parsing TRExFitter results and producing additional
plots/tables.

.. currentmodule:: tdub.rex

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   FitParam

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   available_regions
   chisq
   chisq_text
   compare_nuispar
   compare_uncertainty
   comparison_summary
   data_histogram
   delta_param
   delta_poi
   fit_parameter
   meta_axis_label
   meta_text
   nuispar_impact
   nuispar_impacts
   nuispar_impact_plot_df
   nuispar_impact_plot_top20
   plot_all_regions
   plot_region_stage_ff
   prefit_total_and_uncertainty
   prefit_histogram
   prefit_histograms
   prettify_label
   postfit_available
   postfit_total_and_uncertainty
   postfit_histogram
   postfit_histograms
   stability_test_standard
   stability_test_parton_shower_impacts
   stack_canvas

Reference
^^^^^^^^^

.. autoclass:: FitParam
.. autofunction:: available_regions
.. autofunction:: chisq
.. autofunction:: chisq_text
.. autofunction:: compare_nuispar
.. autofunction:: compare_uncertainty
.. autofunction:: comparison_summary
.. autofunction:: data_histogram
.. autofunction:: delta_param
.. autofunction:: delta_poi
.. autofunction:: fit_parameter
.. autofunction:: plot_all_regions
.. autofunction:: plot_region_stage_ff
.. autofunction:: meta_axis_label
.. autofunction:: meta_text
.. autofunction:: nuispar_impact
.. autofunction:: nuispar_impacts
.. autofunction:: nuispar_impact_plot_df
.. autofunction:: nuispar_impact_plot_top20
.. autofunction:: prefit_total_and_uncertainty
.. autofunction:: prefit_histogram
.. autofunction:: prefit_histograms
.. autofunction:: prettify_label
.. autofunction:: postfit_available
.. autofunction:: postfit_total_and_uncertainty
.. autofunction:: postfit_histogram
.. autofunction:: postfit_histograms
.. autofunction:: stability_test_standard
.. autofunction:: stability_test_parton_shower_impacts
.. autofunction:: stack_canvas
